@@ -80,7 +80,8 @@ static int cb_ipfilter_rule(const struct filterent *ent,
       APP(rule, "block return-icmp-as-dest(port-unr)");
     break;
   default:
-    abort();
+    fprintf(stderr, "invalid target: %d\n", ent->target);
+    return -1;
   }
 
   /* in or out? */
@@ -92,8 +93,8 @@ static int cb_ipfilter_rule(const struct filterent *ent,
     APPS(rule, "out");
     break;
   default:
-    fprintf(stderr, "unknown direction\n");
-    abort();
+    fprintf(stderr, "invalid direction: %d\n", ent->direction);
+    return -1;
   }
 
   if (ESET(ent, LOG))
@@ -136,6 +137,5 @@ int fg_ipfilter(struct filter *filter, int flags) {
 
   filter_nogroup(filter);
   filter_unroll(&filter);
-  filter_apply_flags(filter, flags);
   return filtergen_cprod(filter, &cb_ipfilter, &misc);
 }
