@@ -190,8 +190,9 @@ struct filter *new_filter_host(enum filtertype type, const char *matchstr,
       }
       break;
     default:
-      fprintf(stderr, "can't parse netmask \"%s\" for unknown address family\n",
-              mask);
+      fprintf(stderr,
+              "can't parse netmask \"%s\" for invalid address family %d\n",
+              mask, family);
       return NULL;
     }
   }
@@ -409,72 +410,3 @@ void filter_nogroup(struct filter *f) {
 void filter_noneg(struct filter **f) { if (f) { };
   return;
 }
-
-/*
- * Apply flags to the tree
- */
-void filter_apply_flags(struct filter *f, long flags) {
-  struct filter *s;
-  if (!f)
-    return;
-  switch (f->type) {
-  /* Structural things */
-  case F_SIBLIST:
-    for (s = f->u.sib; s; s = s->next)
-      filter_apply_flags(s, flags);
-    break;
-  case F_SUBGROUP:
-    filter_apply_flags(f->u.sub.list, flags);
-    break;
-  case F_NEG:
-    filter_apply_flags(f->u.neg, flags);
-    break;
-  /* Real things */
-  case F_SPORT:
-  case F_DPORT:
-    if (flags & FF_LOOKUP) {
-      struct port_spec *p = &f->u.ports;
-      if (p->min == -1) {
-        fprintf(stderr, "warning: couldn't lookup service \"%s\"\n", p->minstr);
-        break;
-      }
-      free(p->minstr);
-      p->minstr = int_to_str_dup(p->min);
-      if (p->maxstr) {
-        if (p->max == -1) {
-          fprintf(stderr, "warning: couldn't lookup service \"%s\"\n",
-                  p->minstr);
-          break;
-        }
-        free(p->maxstr);
-        p->maxstr = int_to_str_dup(p->max);
-      }
-    }
-    break;
-  case F_SOURCE:
-  case F_DEST:
-    if (flags & FF_LOOKUP) {
-      struct addr_spec *a = &f->u.addrs;
-      struct addrinfo hints;
-      struct addrinfo *info = NULL;
-      memset(&hints, 0, sizeof(struct addrinfo));
-      hints.ai_family = a->family;
-      if (getaddrinfo(a->addrstr, NULL, &hints, &info) == 0) {
-        free(a->addrstr);
-        a->addrstr = malloc(NI_MAXHOST + 1);
-        if (getnameinfo(info->ai_addr, info->ai_addrlen, a->addrstr, NI_MAXHOST,
-                        NULL, 0, NI_NUMERICHOST)) {
-          fprintf(stderr, "warning: can't stringify IP: %s\n", strerror(errno));
-        }
-        freeaddrinfo(info);
-      } else {
-        fprintf(stderr, "warning: can't lookup name \"%s\"\n", a->addrstr);
-      }
-    }
-    break;
-  default:
-    break;
-  }
-  filter_apply_flags(f->child, flags);
-  filter_apply_flags(f->next, flags);
-}
