@@ -55,6 +55,14 @@ void usage(char *prog) {
   fprintf(stderr, "           -c              compile only, no generate\n");
 #endif
 
+#ifdef HAVE_GETOPT_H
+  fprintf(stderr,
+          " --no-resolve/-R           don't resolve hostnames or portnames\n");
+#else
+  fprintf(stderr,
+          "              -R           don't resolve hostnames or portnames\n");
+#endif
+
 #ifdef HAVE_GETOPT_H
   fprintf(
       stderr,
@@ -135,6 +143,7 @@ static struct option long_options[] = {{"help", no_argument, 0, 'h'},
                                        {"compile", no_argument, 0, 'c'},
                                        {"target", required_argument, 0, 't'},
                                        {"output", required_argument, 0, 'o'},
+                                       {"no-resolve", no_argument, 0, 'R'},
                                        {"flush", required_argument, 0, 'F'},
                                        {"version", no_argument, 0, 'V'},
                                        {0, 0, 0, 0}};
@@ -157,7 +166,7 @@ int main(int argc, char **argv) {
 
   progname = argv[0];
 
-  while ((arg = GETOPT(argc, argv, "hco:t:F:V")) > 0) {
+  while ((arg = GETOPT(argc, argv, "hco:t:F:VR")) > 0) {
     switch (arg) {
     case ':':
       usage(progname);
@@ -173,6 +182,9 @@ int main(int argc, char **argv) {
     case 'o':
       ofn = strdup(optarg);
       break;
+    case 'R':
+      flags |= FF_NORESOLVE;
+      break;
     case 't':
       ftn = strdup(optarg);
       break;
@@ -222,6 +234,7 @@ int main(int argc, char **argv) {
   for (ft = filter_types; ft->name; ft++)
     if (!strcmp(ftn, ft->name))
       break;
+  free(ftn);
   if (!ft->name) {
     fprintf(stderr, "%s: target filter unrecognised: %s\n", progname, ftn);
     usage(progname);
@@ -248,7 +261,10 @@ int main(int argc, char **argv) {
         memset(&o, 0, sizeof o);
         o.family = ft->family;
 
-        resolve(&ast, &o);
+        if (!(flags & FF_NORESOLVE)) {
+          resolve(&ast, &o);
+        }
+
         f = convert(&ast, &o);
         if (!f) {
           fprintf(stderr, "couldn't convert file\n");
@@ -278,6 +294,9 @@ int main(int argc, char **argv) {
       unlink(ofn);
     return 1;
   }
+  if (ofn) {
+    free(ofn);
+  }
   fprintf(stderr, "generated %d rules\n", l);
   return 0;
 }
