@@ -17,6 +17,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include <stdlib.h>
 #include <stdio.h>
 #include "filter.h"
 #include "ast.h"
@@ -75,18 +76,23 @@ struct filter *convert_subrule_list(struct subrule_list_s *n,
     printf("error: no content in subrule_list\n");
   }
 
+  free(n);
   return res;
 }
 
 struct filter *convert_compound_specifier(struct compound_specifier_s *r,
                                           struct filtergen_opts *o) {
-  struct filter *res = NULL;
+  struct filter *res = NULL, *sub = NULL;
 
   eprint("converting compound_specifier\n");
 
   if (r->list) {
-    res = new_filter_sibs(convert_subrule_list(r->list, o));
+    sub = convert_subrule_list(r->list, o);
+    if (sub) {
+      res = new_filter_sibs(sub);
+    }
   }
+  free(r);
   return res;
 }
 
@@ -99,7 +105,7 @@ struct filter *convert_direction_argument(struct direction_argument_s *n,
   } else {
     printf("error: no direction argument contents\n");
   }
-
+  free(n);
   return res;
 }
 
@@ -123,9 +129,10 @@ convert_direction_argument_list(struct direction_argument_list_s *n, int type) {
       printf("warning: convert_direction_argument_list returned NULL\n");
     }
   } else {
-    res = convert_direction_argument(n->arg, type);
+    if (n->arg)
+      res = convert_direction_argument(n->arg, type);
   }
-
+  free(n);
   return res;
 }
 
@@ -152,7 +159,7 @@ struct filter *convert_direction(struct direction_specifier_s *n) {
   } else {
     printf("error: no direction argument list\n");
   }
-
+  free(n);
   return res;
 }
 
@@ -177,7 +184,7 @@ struct filter *convert_host_argument(struct host_argument_s *n, int type,
   } else {
     printf("error: no host part\n");
   }
-
+  free(n);
   return res;
 }
 
@@ -201,9 +208,10 @@ struct filter *convert_host_argument_list(struct host_argument_list_s *n,
       printf("warning: convert_host_argument_list returned NULL\n");
     }
   } else {
-    res = convert_host_argument(n->arg, type, o);
+    if (n->arg)
+      res = convert_host_argument(n->arg, type, o);
   }
-
+  free(n);
   return res;
 }
 
@@ -231,7 +239,7 @@ struct filter *convert_host_specifier(struct host_specifier_s *n,
   } else {
     printf("error: no host argument list\n");
   }
-
+  free(n);
   return res;
 }
 
@@ -245,7 +253,7 @@ struct filter *convert_protocol_argument(struct protocol_argument_s *n) {
   } else {
     printf("error: no protocol argument contents\n");
   }
-
+  free(n);
   return res;
 }
 
@@ -269,9 +277,10 @@ convert_protocol_argument_list(struct protocol_argument_list_s *n) {
       printf("warning: convert_protocol_argument_list returned NULL\n");
     }
   } else {
-    res = convert_protocol_argument(n->arg);
+    if (n->arg)
+      res = convert_protocol_argument(n->arg);
   }
-
+  free(n);
   return res;
 }
 
@@ -285,7 +294,7 @@ struct filter *convert_protocol_specifier(struct protocol_specifier_s *n) {
   } else {
     printf("error: no protocol argument list\n");
   }
-
+  free(n);
   return res;
 }
 
@@ -301,16 +310,15 @@ struct filter *convert_port_argument(struct port_argument_s *n, int type) {
         printf("error: asprintf allocation failed when emitting port range "
                "%s:%s\n",
                n->port_min, n->port_max);
-      } else {
-        res = new_filter_ports(type, p);
       }
     } else {
-      res = new_filter_ports(type, n->port_min);
+      p = n->port_min;
     }
+    res = new_filter_ports(type, p);
   } else {
     printf("error: no port argument contents\n");
   }
-
+  free(n);
   return res;
 }
 
@@ -334,9 +342,10 @@ struct filter *convert_port_argument_list(struct port_argument_list_s *n,
       printf("warning: convert_port_argument_list returned NULL\n");
     }
   } else {
-    res = convert_port_argument(n->arg, type);
+    if (n->arg)
+      res = convert_port_argument(n->arg, type);
   }
-
+  free(n);
   return res;
 }
 
@@ -363,7 +372,7 @@ struct filter *convert_port_specifier(struct port_specifier_s *n) {
   } else {
     printf("error: no port argument list\n");
   }
-
+  free(n);
   return res;
 }
 
@@ -377,7 +386,7 @@ struct filter *convert_icmptype_argument(struct icmptype_argument_s *n) {
   } else {
     printf("error: no icmptype argument contents\n");
   }
-
+  free(n);
   return res;
 }
 
@@ -401,9 +410,10 @@ convert_icmptype_argument_list(struct icmptype_argument_list_s *n) {
       printf("warning: convert_icmptype_argument_list returned NULL\n");
     }
   } else {
-    res = convert_icmptype_argument(n->arg);
+    if (n->arg)
+      res = convert_icmptype_argument(n->arg);
   }
-
+  free(n);
   return res;
 }
 
@@ -417,7 +427,7 @@ struct filter *convert_icmptype_specifier(struct icmptype_specifier_s *n) {
   } else {
     printf("error: no icmptype argument list\n");
   }
-
+  free(n);
   return res;
 }
 
@@ -443,7 +453,7 @@ struct filter *convert_option_specifier(struct option_specifier_s *n) {
     printf("error: incorrect option type encountered\n");
     break;
   }
-
+  free(n);
   return res;
 }
 
@@ -467,12 +477,13 @@ struct filter *convert_chaingroup_specifier(struct chaingroup_specifier_s *n,
 
   if (n->list) {
     sub = convert_subrule_list(n->list, o);
-
-    res = new_filter_subgroup(name, sub);
+    if (sub) {
+      res = new_filter_subgroup(name, sub);
+    }
   } else {
     printf("error: no list in chaingroup\n");
   }
-
+  free(n);
   return res;
 }
 
@@ -528,9 +539,10 @@ struct filter *convert_specifier(struct specifier_s *r,
     res = convert_option_specifier(r->option);
   } else if (r->chaingroup) {
     res = convert_chaingroup_specifier(r->chaingroup, o);
-  } else
+  } else {
     printf("error: no specifiers\n");
-
+  }
+  free(r);
   return res;
 }
 
@@ -550,6 +562,7 @@ struct filter *convert_negated_specifier(struct negated_specifier_s *r,
       res = spec;
     }
   }
+  free(r);
   return res;
 }
 
@@ -573,9 +586,10 @@ struct filter *convert_specifier_list(struct specifier_list_s *n,
       printf("warning: convert_specifier_list returned NULL\n");
     }
   } else {
-    res = convert_negated_specifier(n->spec, o);
+    if (n->spec)
+      res = convert_negated_specifier(n->spec, o);
   }
-
+  free(n);
   return res;
 }
 
@@ -586,6 +600,7 @@ struct filter *convert_rule(struct rule_s *r, struct filtergen_opts *o) {
 
   if (r->list)
     res = convert_specifier_list(r->list, o);
+  free(r);
   return res;
 }
 
@@ -597,17 +612,21 @@ struct filter *convert_rule_list(struct rule_list_s *n,
 
   if (n->list) {
     res = convert_rule_list(n->list, o);
-    end = res;
-    while (end->next) {
-      end = end->next;
+    if (res) {
+      end = res;
+      while (end->next) {
+        end = end->next;
+      }
     }
-    if (n->rule) {
-      end->next = convert_rule(n->rule, o);
-    }
-  } else {
-    res = convert_rule(n->rule, o);
   }
-
+  if (n->rule) {
+    if (end) {
+      end->next = convert_rule(n->rule, o);
+    } else {
+      res = convert_rule(n->rule, o);
+    }
+  }
+  free(n);
   return res;
 }
 
@@ -616,8 +635,10 @@ struct filter *convert(struct ast_s *ast, struct filtergen_opts *o) {
 
   eprint("converting ast\n");
 
-  if (ast->list)
+  if (ast->list) {
     res = convert_rule_list(ast->list, o);
+}
+
   return res;
 }
 
